pub struct Mbuf<'a> { /* private fields */ }
View of an os_mbuf, the data buffers used by NimBLE
Copy this Mbuf into buf, returning the number of bytes copied or error if buf is too small
buf
Append buf to the mbuf.
TypeId
self
Returns the argument unchanged.
Calls U::from(self).
U::from(self)
That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.
[From]<T> for U